==========
 Examples
==========

This page lists example character files. These files are found in the
``examples/`` directory, and can be compiled with ``$ makesheets
examples/``.

.. contents:: :local:

Artificer
=========

.. literalinclude:: ../examples/artificer1.py

Barbarian
=========

.. literalinclude:: ../examples/barbarian1.py

.. literalinclude:: ../examples/barbarian2.py
		    
Bard
====

.. literalinclude:: ../examples/bard1.py

.. literalinclude:: ../examples/bard2.py

Cleric
======

.. literalinclude:: ../examples/cleric1.py

.. literalinclude:: ../examples/cleric2.py

Druid
=====

.. literalinclude:: ../examples/druid1.py

.. literalinclude:: ../examples/druid2.py

.. literalinclude:: ../examples/druid3.py

Fighter
=======

.. literalinclude:: ../examples/fighter1.py

.. literalinclude:: ../examples/fighter2.py


.. _homebrew example:

Homebrew
========

.. literalinclude:: ../examples/homebrew.py

Monk
====

.. literalinclude:: ../examples/monk1.py

.. literalinclude:: ../examples/monk2.py

Multi-Classing
==============

.. literalinclude:: ../examples/multiclass1.py

.. literalinclude:: ../examples/multiclass2.py

Paladin
=======

.. literalinclude:: ../examples/paladin1.py

.. literalinclude:: ../examples/paladin2.py

Ranger
======

.. literalinclude:: ../examples/ranger1.py

.. literalinclude:: ../examples/ranger2.py

.. literalinclude:: ../examples/ranger3.py

Rogue
=====

.. literalinclude:: ../examples/rogue1.py

.. literalinclude:: ../examples/rogue2.py

Sorceror
=========

.. literalinclude:: ../examples/sorceror1.py

.. literalinclude:: ../examples/sorceror2.py

Warlock
=======

.. literalinclude:: ../examples/warlock1.py

.. literalinclude:: ../examples/warlock2.py

Wizard
======

.. literalinclude:: ../examples/wizard1.py

.. literalinclude:: ../examples/wizard2.py
